import { PitayaAppConfiguration } from "./app-configuration";
import { ISetting }               from "./database/indexed-db.d";
import { PitayaIndexedDb }        from "./index";

const _SETTINGS_NAME_FIELD_NAME: string = PitayaAppConfiguration.Database.settingsNameFieldName;

const settingsDb = PitayaIndexedDb.settings;

export const PitayaSettings = {
	/**
	 * Returns the value for the given key
	 * @param key {string}
	 * @returns {Promise<ISetting>}
	 */
	async get( key: string ): Promise<ISetting>
	{
		return await settingsDb
			.where( _SETTINGS_NAME_FIELD_NAME )
			.equals( key )
			.first();
	},
	/**
	 * Sets the value for a given key
	 * @param data {object}
	 * @returns {Promise<number>}
	 */
	async set( data ): Promise<number>
	{
		return await settingsDb.add( data );
	},
	/**
	 * Updates the value for a given key
	 * @param key {string}
	 * @param data {object}
	 * @returns {Promise<number>}
	 */
	async update( key: string, data ): Promise<number>
	{
		return await settingsDb
			.where( _SETTINGS_NAME_FIELD_NAME )
			.equals( key )
			.modify( data );
	},
	/**
	 * Indicates weather setting exists or not
	 * @param key {string}
	 * @returns {Promise<boolean>}
	 */
	async has( key: string ): Promise<boolean>
	{
		return await settingsDb
			.where( _SETTINGS_NAME_FIELD_NAME )
			.equals( key )
			.count() > 0;
	}
};